@@ -1,9 +1,11 @@
 use crate::cli::commands::builds::Builds;
 use crate::cli::commands::empties::Empties;
+use crate::cli::commands::supported::Supported;
 
 pub mod actions;
 pub mod builds;
 pub mod empties;
+pub mod supported;
 
 /// `cleaner` subcommands defined
 #[derive(Debug, Eq, PartialEq, Subcommand)]
@@ -14,6 +16,6 @@ pub enum Commands {
     /// Manage empty folders
     Empties(Empties),
 
-    /// List supported development platforms
-    Supported,
+    /// Manage supported development platforms
+    Supported(Supported),
 }
